# -*- coding: utf-8 -*-
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from cms.models.pluginmodel import CMSPlugin


###################################
## CMS MODELS                    ##
###################################

class VideoSettings(CMSPlugin):

    area_slug = models.SlugField(
        _("Area slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)Video area slug(s) filter")
    )
    slug = models.SlugField(
        _("Slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)Video slug(s) filter")
    )
    exclusion_area_slug = models.SlugField(
        _("Excluding area slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding video area slug(s) filter")
    )
    exclusion_slug = models.SlugField(
        _("Excluding slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding video slug(s) filter")
    )
#    pub_date_begin = models.DateTimeField(
#        blank=True,
#        null=True,
#        verbose_name=_('Publication date begin'),
#        help_text=_('Video publication start datetime'),
#    )
#    pub_date_end = models.DateTimeField(
#        blank=True,
#        null=True,
#        verbose_name=_('Publication date end'),
#        help_text=_('Video publication datetime'),
#    )

    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='ordering, titolo'
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.VIDEO_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/video/video_list.html",
        editable=len(settings.VIDEO_CMSPLUGIN_TEMPLATES)>1
    )
#    video_thumb_width = models.IntegerField(
#        _("Video thumbnail width (in px)"),
#        default=200
#    )
#    video_thumb_heigth = models.IntegerField(
#        _("Video thumbnail heigth (in px)"),
#        default=100
#    )

    def __unicode__(self):
        if self.slug:
            return self.slug
        if self.area_slug:
            return self.area_slug
        return self.template_name

    class Meta:
        app_label = "video"



class LastVideoSettings(CMSPlugin):

    area_slug = models.SlugField(
        _("Area slug"),
        max_length=100,
        help_text=_("Video area slug: it will be shown the latest video of the area according to ordering")
    )
    slug = models.SlugField(
        _("Slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)Video slug filter: put here the video slug if you want to show only that video")
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='-date_last_modify, ordering, titolo'
    )
    autoplay_main_video = models.BooleanField(
        _("Autoplay main video"),
        default=False
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.VIDEO_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/video/last_video.html",
        editable=len(settings.VIDEO_CMSPLUGIN_TEMPLATES)>1
    )

    def __unicode__(self):
        if self.slug:
            return self.slug
        if self.area_slug:
            return self.area_slug
        return self.template_name

    class Meta:
        app_label = "video"