from django.core.paginator import Paginator
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.video.models import Video, AreaVideo
from jmb.video.cms.models import VideoSettings, LastVideoSettings


###################################
## CMS PLUGINS                    #
###################################

class VideoPlugin(CMSPluginBase):
    model = VideoSettings
    name = _("Video List")
    module = _("Video")


    def render(self, context, instance, placeholder):
        page = 1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")

        objects = Video.objects.filter(status=1)

        if instance.slug:
            slugs = instance.slug.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)
        if instance.area_slug:
            area_slugs = instance.area_slug.lower().replace(" ","").split(",")
            objects = objects.filter(categories__slug__in = area_slugs)
        if instance.exclusion_slug:
            exclusion_slugs = instance.exclusion_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)
        if instance.exclusion_area_slug:
            exclusion_area_slugs = instance.exclusion_area_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = exclusion_area_slugs)
#        if instance.pub_date_begin:
#            objects = objects.filter(pub_date_begin__gte = instance.pub_date_begin)
#        if instance.pub_date_end:
#            objects = objects.filter(event_date__lte= instance.pub_date_end)

        objects = objects.order_by(*ordering)
        paginator = Paginator(objects, instance.objects_per_page)

        objects = paginator.page(page)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(VideoPlugin)


class LastVideoPlugin(CMSPluginBase):
    model = LastVideoSettings
    name = _("Last Video")
    module = _("Video")

    def render(self, context, instance, placeholder):
            self.render_template = instance.template_name
            page = 1
            ordering = instance.ordering.lower().replace(" ","").split(",")


            if instance.slug:
                objects = []
                try:
                    obj = Video.objects.get(slug=instance.slug)
                    if obj.status == 1:
                        objects.append(obj)
                except:
                    pass
            else:
                objects = Video.objects.filter(status=1)
                if instance.area_slug:
                    area_slugs = instance.area_slug.lower().replace(" ","").split(",")
                    objects = objects.filter(area__slug__in = area_slugs)

                objects = objects.order_by(*ordering)

            context.update({
                        'objects': objects,
                        'instance':instance,
                        'placeholder':placeholder,
                    })
            return context

plugin_pool.register_plugin(LastVideoPlugin)

#class ModelSearchPlugin(CMSPluginBase):
#    model = ModelSearchSettings
#    name = _("Product Search")

#    def render(self, context, instance, placeholder):
#        self.render_template = instance.template_name
#        context.update({
#            'instance':instance,
#            'placeholder':placeholder,
#        })
#        return context

#plugin_pool.register_plugin(ModelSearchPlugin)
